// -*-C++-*-
// This file is part of the gmod package
// Copyright (C) 1997 by Andrew J. Robinson

#ifndef ultH
#define ultH

#include "Sample.h"

class ULT_sample : public Sample
{
public:
  int load(Sequencer &, FILE *, int, int, void *, void *);
};

#endif
